@@ -1,7 +1,15 @@
+#ifndef  USE_FC_LEN_T
+    #define USE_FC_LEN_T
+#endif
+#include <Rconfig.h>
+#include <R_ext/BLAS.h>
+#include <R_ext/Lapack.h>
+#ifndef FCONE
+    #define FCONE
+#endif
+
 #include <R.h>
 #include <Rmath.h>
-#include <R_ext/Lapack.h>
-#include <R_ext/BLAS.h>
 #include "regdata.h"
 
 #ifdef _OPENMP
